@@ -1,20 +1,13 @@
-/*************************************************************************
- *  Copyright (C) 2008,2009,2011 by Volker Lanz <vl@fidra.de>            *
- *  Copyright (C) 2017 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2011 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2013-2018 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2017 Pali Rohár <pali.rohar@gmail.com>
+    SPDX-FileCopyrightText: 2020 Arnaud Ferraris <arnaud.ferraris@collabora.com>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "fs/fat12.h"
 
@@ -49,7 +42,7 @@ FileSystem::CommandSupportType fat12::m_Backup = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType fat12::m_UpdateUUID = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType fat12::m_GetUUID = FileSystem::cmdSupportNone;
 
-fat12::fat12(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features, FileSystem::Type t) :
+fat12::fat12(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QVariantMap& features, FileSystem::Type t) :
     FileSystem(firstsector, lastsector, sectorsused, label, features, t)
 {
 }
@@ -66,8 +59,8 @@ void fat12::init()
     m_GetUUID = cmdSupportCore;
 
     if (m_Create == cmdSupportFileSystem) {
-        addAvailableFeature(QStringLiteral("sector-size"), FSFeature::Type::Int);
-        addAvailableFeature(QStringLiteral("sectors-per-cluster"), FSFeature::Type::Int);
+        addAvailableFeature(QStringLiteral("sector-size"));
+        addAvailableFeature(QStringLiteral("sectors-per-cluster"));
     }
 }
 
@@ -169,17 +162,18 @@ bool fat12::createWithFatSize(Report &report, const QString& deviceNode, int fat
     if (fatSize != 12 && fatSize != 16 && fatSize != 32)
         return false;
 
-    for (auto f : this->features()) {
-        if (f.name() == QStringLiteral("sector-size")) {
-            quint32 sectorSize = f.iValue();
+    for (const auto& k : this->features().keys()) {
+	const auto& v = this->features().value(k);
+        if (k == QStringLiteral("sector-size")) {
+            quint32 sectorSize = v.toInt();
 
             /* sectorSize has to be a power of 2 between 512 and 32768 */
             if (sectorSize >= 512 && sectorSize <= 32768 && sectorSize == qNextPowerOfTwo(sectorSize - 1))
                 args << QStringLiteral("-S%1").arg(sectorSize);
             else
                 qWarning() << QStringLiteral("FAT sector size %1 is invalid, using default").arg(sectorSize);
-        } else if (f.name() == QStringLiteral("sectors-per-cluster")) {
-            quint32 sectorsPerCluster = f.iValue();
+        } else if (k == QStringLiteral("sectors-per-cluster")) {
+            quint32 sectorsPerCluster = v.toInt();
 
             /* sectorsPerCluster has to be a power of 2 between 2 and 128 */
             if (sectorsPerCluster <= 128 && sectorsPerCluster == qNextPowerOfTwo(sectorsPerCluster - 1))
